#include "MainComponent.h"


MainComponent::MainComponent()
{
    mp_editor.reset(new juce::CodeEditorComponent(m_code_document, nullptr));
    mp_editor->setLineNumbersShown(false);
    mp_editor->setColour(juce::CodeEditorComponent::ColourIds::backgroundColourId, juce::Colour(0xFF555555));
    mp_editor->setColour(juce::CodeEditorComponent::ColourIds::highlightColourId, juce::Colour(0xFFAA5533));
    addAndMakeVisible(mp_editor.get());

    juce::String text;
    text << "Click this area with mouse, then type keyboard keys";

    m_help_text.setText(text, juce::NotificationType::dontSendNotification);
    addAndMakeVisible(m_help_text);
    
    setWantsKeyboardFocus(true);
    setSize(800, 600);
}


MainComponent::~MainComponent()
{
}


bool MainComponent::keyPressed(const juce::KeyPress& key)
{
    const int  key_code  = key.getKeyCode();
    const auto character = key.getTextCharacter();
    const int  decimal   = character;

    juce::String text;
    text << "keyPressed(): " << key_code << ", " << decimal << ", " << "L'" << character << "'\n\n";

    mp_editor->insertTextAtCaret(text);

    return true;
}


bool MainComponent::keyStateChanged(bool isKeyDown)
{
    if (!isKeyDown)
        return false;

    juce::String text;

    text << "keyStateChanged(): ";

    for (int i = 0; i < 10240; ++i)
        if (juce::KeyPress::isKeyCurrentlyDown(i))
            text << i << ", ";

    text << "\n";
    mp_editor->insertTextAtCaret(text);

    return false;
}


void MainComponent::paint(juce::Graphics& g)
{
    g.fillAll(getLookAndFeel().findColour (juce::ResizableWindow::backgroundColourId));
}


void MainComponent::resized()
{
    m_help_text.setBounds(0, 0, 1200, 200);
    mp_editor->setBounds(0, 200, getWidth(), getHeight() - 200);
}
